Learn R Programming

LongDecompHE (version 0.1.0)

decom_results: Decomposition Results Comparing Two Populations

Description

Decomposition results obtained from the Decomp_sullivan() function. This object includes age-cause-specific mortality, disability, and total effects to differences in cohort health expectancy (HE).

Usage

data(decom_results)

Arguments

Format

A list with the following components:

mortality_effect

A matrix with rows representing total, background, and causes (e.g., Z1, Z2, Z3), and columns representing age groups. Each cell indicates the contribution of a given cause to the mortality effect on health expectancy differences.

disability_effect

A matrix structured as above, representing contributions to the disability effect.

total_effect

A matrix summing the mortality and disability effects for each cause at each age.

population1_HE

Numeric value of cohort health expectancy (HE) in population 1.

population2_HE

Numeric value of cohort health expectancy (HE) in population 2.

population1_LE

Numeric value of cohort life expectancy (LE) in population 1.

population2_LE

Numeric value of cohort life expectancy (LE) in population 2.

var_list

A character vector of cause names (e.g., c("Z1", "Z2", "Z3")).

time_list

An integer vector indicating age groups.

copula

A string indicating the method used for decomposition, e.g., "Decomposition_sullivan".

Examples

Run this code
  data(decom_results)
  str(decom_results)

Run the code above in your browser using DataLab