Decomposition results obtained from the Decomp_sullivan() function. This object includes age-cause-specific mortality, disability, and total effects to differences in cohort health expectancy (HE).
data(decom_results)A list with the following components:
mortality_effectA matrix with rows representing total, background, and causes (e.g., Z1, Z2, Z3), and columns representing age groups. Each cell indicates the contribution of a given cause to the mortality effect on health expectancy differences.
disability_effectA matrix structured as above, representing contributions to the disability effect.
total_effectA matrix summing the mortality and disability effects for each cause at each age.
population1_HENumeric value of cohort health expectancy (HE) in population 1.
population2_HENumeric value of cohort health expectancy (HE) in population 2.
population1_LENumeric value of cohort life expectancy (LE) in population 1.
population2_LENumeric value of cohort life expectancy (LE) in population 2.
var_listA character vector of cause names (e.g., c("Z1", "Z2", "Z3")).
time_listAn integer vector indicating age groups.
copulaA string indicating the method used for decomposition, e.g., "Decomposition_sullivan".
data(decom_results)
str(decom_results)
Run the code above in your browser using DataLab